[Glibc-bsd-commits] r4558 - in trunk/glibc-ports/fbtl: . sysdeps/i386 sysdeps/i386/i686 sysdeps/pthread sysdeps/x86_64

Petr Salinger ps-guest at alioth.debian.org
Mon Jul 8 12:42:37 UTC 2013


Author: ps-guest
Date: 2013-06-21 16:48:17 +0000 (Fri, 21 Jun 2013)
New Revision: 4558

Modified:
   trunk/glibc-ports/fbtl/sysdeps/i386/Makefile
   trunk/glibc-ports/fbtl/sysdeps/i386/i686/Makefile
   trunk/glibc-ports/fbtl/sysdeps/i386/tls.h
   trunk/glibc-ports/fbtl/sysdeps/pthread/Makefile
   trunk/glibc-ports/fbtl/sysdeps/pthread/Subdirs
   trunk/glibc-ports/fbtl/sysdeps/pthread/librt-cancellation.c
   trunk/glibc-ports/fbtl/sysdeps/pthread/sigfillset.c
   trunk/glibc-ports/fbtl/sysdeps/pthread/sigprocmask.c
   trunk/glibc-ports/fbtl/sysdeps/x86_64/Makefile
   trunk/glibc-ports/fbtl/sysdeps/x86_64/tls.h
   trunk/glibc-ports/fbtl/tst-tls6.sh
Log:
more nptl -> fbtl


Modified: trunk/glibc-ports/fbtl/sysdeps/i386/Makefile
===================================================================
--- trunk/glibc-ports/fbtl/sysdeps/i386/Makefile	2013-06-21 15:23:46 UTC (rev 4557)
+++ trunk/glibc-ports/fbtl/sysdeps/i386/Makefile	2013-06-21 16:48:17 UTC (rev 4558)
@@ -19,7 +19,7 @@
 gen-as-const-headers += tcb-offsets.sym
 endif
 
-ifeq ($(subdir),nptl)
+ifeq ($(subdir),fbtl)
 CFLAGS-pthread_create.c += -mpreferred-stack-boundary=4
 CFLAGS-tst-align.c += -mpreferred-stack-boundary=4
 CFLAGS-tst-align2.c += -mpreferred-stack-boundary=4

Modified: trunk/glibc-ports/fbtl/sysdeps/i386/i686/Makefile
===================================================================
--- trunk/glibc-ports/fbtl/sysdeps/i386/i686/Makefile	2013-06-21 15:23:46 UTC (rev 4557)
+++ trunk/glibc-ports/fbtl/sysdeps/i386/i686/Makefile	2013-06-21 16:48:17 UTC (rev 4558)
@@ -16,7 +16,7 @@
 # License along with the GNU C Library; if not, see
 # <http://www.gnu.org/licenses/>.
 
-ifeq ($(subdir),nptl)
+ifeq ($(subdir),fbtl)
 # It turns out that stack coloring is in general not good on P4s.  Some
 # applications will benefit.  We will probably have a configuration option
 # at some point.  Enabling coloring can be done with

Modified: trunk/glibc-ports/fbtl/sysdeps/i386/tls.h
===================================================================
--- trunk/glibc-ports/fbtl/sysdeps/i386/tls.h	2013-06-21 15:23:46 UTC (rev 4557)
+++ trunk/glibc-ports/fbtl/sysdeps/i386/tls.h	2013-06-21 16:48:17 UTC (rev 4558)
@@ -105,7 +105,7 @@
 
 
 /* Get the thread descriptor definition.  */
-# include <nptl/descr.h>
+# include <fbtl/descr.h>
 
 /* This is the size of the initial TCB.  Can't be just sizeof (tcbhead_t),
    because NPTL getpid, __libc_alloca_cutoff etc. need (almost) the whole

Modified: trunk/glibc-ports/fbtl/sysdeps/pthread/Makefile
===================================================================
--- trunk/glibc-ports/fbtl/sysdeps/pthread/Makefile	2013-06-21 15:23:46 UTC (rev 4557)
+++ trunk/glibc-ports/fbtl/sysdeps/pthread/Makefile	2013-06-21 16:48:17 UTC (rev 4558)
@@ -16,7 +16,7 @@
 # License along with the GNU C Library; if not, see
 # <http://www.gnu.org/licenses/>.
 
-ifeq ($(subdir),nptl)
+ifeq ($(subdir),fbtl)
 libpthread-sysdep_routines += errno-loc
 endif
 
@@ -37,5 +37,5 @@
 endif
 
 ifeq ($(subdir),posix)
-CFLAGS-confstr.c += -DLIBPTHREAD_VERSION='"NPTL $(version)"'
+CFLAGS-confstr.c += -DLIBPTHREAD_VERSION='"FBTL $(version)"'
 endif

Modified: trunk/glibc-ports/fbtl/sysdeps/pthread/Subdirs
===================================================================
--- trunk/glibc-ports/fbtl/sysdeps/pthread/Subdirs	2013-06-21 15:23:46 UTC (rev 4557)
+++ trunk/glibc-ports/fbtl/sysdeps/pthread/Subdirs	2013-06-21 16:48:17 UTC (rev 4558)
@@ -1,2 +1,2 @@
-nptl
-nptl_db
+fbtl
+fbtl_db

Modified: trunk/glibc-ports/fbtl/sysdeps/pthread/librt-cancellation.c
===================================================================
--- trunk/glibc-ports/fbtl/sysdeps/pthread/librt-cancellation.c	2013-06-21 15:23:46 UTC (rev 4557)
+++ trunk/glibc-ports/fbtl/sysdeps/pthread/librt-cancellation.c	2013-06-21 16:48:17 UTC (rev 4558)
@@ -21,4 +21,4 @@
 
 #define __pthread_enable_asynccancel __librt_enable_asynccancel
 #define __pthread_disable_asynccancel __librt_disable_asynccancel
-#include <nptl/cancellation.c>
+#include <fbtl/cancellation.c>

Modified: trunk/glibc-ports/fbtl/sysdeps/pthread/sigfillset.c
===================================================================
--- trunk/glibc-ports/fbtl/sysdeps/pthread/sigfillset.c	2013-06-21 15:23:46 UTC (rev 4557)
+++ trunk/glibc-ports/fbtl/sysdeps/pthread/sigfillset.c	2013-06-21 16:48:17 UTC (rev 4558)
@@ -15,6 +15,6 @@
    License along with the GNU C Library; if not, see
    <http://www.gnu.org/licenses/>.  */
 
-#include <nptl/pthreadP.h>
+#include <fbtl/pthreadP.h>
 
 #include <signal/sigfillset.c>

Modified: trunk/glibc-ports/fbtl/sysdeps/pthread/sigprocmask.c
===================================================================
--- trunk/glibc-ports/fbtl/sysdeps/pthread/sigprocmask.c	2013-06-21 15:23:46 UTC (rev 4557)
+++ trunk/glibc-ports/fbtl/sysdeps/pthread/sigprocmask.c	2013-06-21 16:48:17 UTC (rev 4558)
@@ -15,5 +15,5 @@
    License along with the GNU C Library; if not, see
    <http://www.gnu.org/licenses/>.  */
 
-#include <nptl/pthreadP.h>
-#include <sysdeps/unix/sysv/linux/sigprocmask.c>
+#include <fbtl/pthreadP.h>
+#include <sysdeps/unix/bsd/sigprocmask.c>

Modified: trunk/glibc-ports/fbtl/sysdeps/x86_64/Makefile
===================================================================
--- trunk/glibc-ports/fbtl/sysdeps/x86_64/Makefile	2013-06-21 15:23:46 UTC (rev 4557)
+++ trunk/glibc-ports/fbtl/sysdeps/x86_64/Makefile	2013-06-21 16:48:17 UTC (rev 4558)
@@ -19,7 +19,7 @@
 gen-as-const-headers += tcb-offsets.sym
 endif
 
-ifeq ($(subdir),nptl)
+ifeq ($(subdir),fbtl)
 # P4s have problems with 4M aliasing.  We disturb the allocation of stacks
 # just enough so the subsequent allocations do not use stack address
 # (mod 4M) == 0.

Modified: trunk/glibc-ports/fbtl/sysdeps/x86_64/tls.h
===================================================================
--- trunk/glibc-ports/fbtl/sysdeps/x86_64/tls.h	2013-06-21 15:23:46 UTC (rev 4557)
+++ trunk/glibc-ports/fbtl/sysdeps/x86_64/tls.h	2013-06-21 16:48:17 UTC (rev 4558)
@@ -94,7 +94,7 @@
 
 
 /* Get the thread descriptor definition.  */
-# include <nptl/descr.h>
+# include <fbtl/descr.h>
 
 #ifndef LOCK_PREFIX
 # ifdef UP

Modified: trunk/glibc-ports/fbtl/tst-tls6.sh
===================================================================
--- trunk/glibc-ports/fbtl/tst-tls6.sh	2013-06-21 15:23:46 UTC (rev 4557)
+++ trunk/glibc-ports/fbtl/tst-tls6.sh	2013-06-21 16:48:17 UTC (rev 4558)
@@ -22,11 +22,11 @@
 common_objpfx=$1; shift
 test_via_rtld_prefix=$1; shift
 test_wrapper_env=$1; shift
-logfile=$common_objpfx/nptl/tst-tls6.out
+logfile=$common_objpfx/fbtl/tst-tls6.out
 
-# We have to find libc and nptl
-library_path=${common_objpfx}:${common_objpfx}nptl
-tst_tls5="${test_via_rtld_prefix} ${common_objpfx}/nptl/tst-tls5"
+# We have to find libc and fbtl
+library_path=${common_objpfx}:${common_objpfx}fbtl
+tst_tls5="${test_via_rtld_prefix} ${common_objpfx}/fbtl/tst-tls5"
 
 LC_ALL=C
 export LC_ALL
@@ -40,21 +40,21 @@
   echo "preload tst-tls5mod{$aligned,b,c,d}.so" >> $logfile
   echo "===============" >> $logfile
   ${test_wrapper_env} \
-  LD_PRELOAD="`echo ${common_objpfx}nptl/tst-tls5mod{$aligned,b,c,d}.so \
+  LD_PRELOAD="`echo ${common_objpfx}fbtl/tst-tls5mod{$aligned,b,c,d}.so \
 	      | sed 's/:$//;s/: /:/g'`" ${tst_tls5} >> $logfile || fail=1
   echo >> $logfile
 
   echo "preload tst-tls5mod{b,$aligned,c,d}.so" >> $logfile
   echo "===============" >> $logfile
   ${test_wrapper_env} \
-  LD_PRELOAD="`echo ${common_objpfx}nptl/tst-tls5mod{b,$aligned,c,d}.so \
+  LD_PRELOAD="`echo ${common_objpfx}fbtl/tst-tls5mod{b,$aligned,c,d}.so \
 	      | sed 's/:$//;s/: /:/g'`" ${tst_tls5} >> $logfile || fail=1
   echo >> $logfile
 
   echo "preload tst-tls5mod{b,c,d,$aligned}.so" >> $logfile
   echo "===============" >> $logfile
   ${test_wrapper_env} \
-  LD_PRELOAD="`echo ${common_objpfx}nptl/tst-tls5mod{b,c,d,$aligned}.so \
+  LD_PRELOAD="`echo ${common_objpfx}fbtl/tst-tls5mod{b,c,d,$aligned}.so \
 	      | sed 's/:$//;s/: /:/g'`" ${tst_tls5} >> $logfile || fail=1
   echo >> $logfile
 done
@@ -62,14 +62,14 @@
 echo "preload tst-tls5mod{d,a,b,c,e}" >> $logfile
 echo "===============" >> $logfile
 ${test_wrapper_env} \
-LD_PRELOAD="`echo ${common_objpfx}nptl/tst-tls5mod{d,a,b,c,e}.so \
+LD_PRELOAD="`echo ${common_objpfx}fbtl/tst-tls5mod{d,a,b,c,e}.so \
 	    | sed 's/:$//;s/: /:/g'`" ${tst_tls5} >> $logfile || fail=1
 echo >> $logfile
 
 echo "preload tst-tls5mod{d,a,b,e,f}" >> $logfile
 echo "===============" >> $logfile
 ${test_wrapper_env} \
-LD_PRELOAD="`echo ${common_objpfx}nptl/tst-tls5mod{d,a,b,e,f}.so \
+LD_PRELOAD="`echo ${common_objpfx}fbtl/tst-tls5mod{d,a,b,e,f}.so \
 	    | sed 's/:$//;s/: /:/g'`" ${tst_tls5} >> $logfile || fail=1
 echo >> $logfile
 




More information about the Glibc-bsd-commits mailing list